
Double
======

An integer



Quickstart
-----------

.. code-block:: python

   from janis_core.types.common_data_types import Double

   w = WorkflowBuilder("my_workflow")

   w.input("input_double", Double(optional=False))
   
   # ...other workflow steps

*This page was automatically generated on 2020-12-22*.
